@@ -207,33 +207,35 @@ double PolyaGamma::draw_like_devroye(double Z, RNG& r)
 
 double PolyaGamma::jj_m1(double b, double z) 
 {
-  double m1 = 0.0;
-  if (z > 1e-12)
-    m1 = b * tanh(z) / z;
-  else
-    m1 = b * (1 - (1.0/3) * pow(z,2) + (2.0/15) * pow(z,4) - (17.0/315) * pow(z,6));
-  return m1;
+    z = fabs(z);
+    double m1 = 0.0;
+    if (z > 1e-12)
+	m1 = b * tanh(z) / z;
+    else
+	m1 = b * (1 - (1.0/3) * pow(z,2) + (2.0/15) * pow(z,4) - (17.0/315) * pow(z,6));
+    return m1;
 }
 
 double PolyaGamma::jj_m2(double b, double z)
 {
-  double m2 = 0.0;
-  if (z > 1e-12)
-    m2 = (b+1) * b * pow(tanh(z)/z,2) + b * ((tanh(z)-z)/pow(z,3));
-  else
-    m2 = (b+1) * b * pow(1 - (1.0/3) * pow(z,2) + (2.0/15) * pow(z,4) - (17.0/315) * pow(z,6), 2) +
-	b * ((-1.0/3) + (2.0/15) * pow(z,2) - (17.0/315) * pow(z,4));
-  return m2;
+    z = fabs(z);
+    double m2 = 0.0;
+    if (z > 1e-12)
+	m2 = (b+1) * b * pow(tanh(z)/z,2) + b * ((tanh(z)-z)/pow(z,3));
+    else
+	m2 = (b+1) * b * pow(1 - (1.0/3) * pow(z,2) + (2.0/15) * pow(z,4) - (17.0/315) * pow(z,6), 2) +
+	    b * ((-1.0/3) + (2.0/15) * pow(z,2) - (17.0/315) * pow(z,4));
+    return m2;
 }
 
 double PolyaGamma::pg_m1(double b, double z)
 {
-  return jj_m1(b, 0.5 * z) * 0.25;
+    return jj_m1(b, 0.5 * z) * 0.25;
 }
  
 double PolyaGamma::pg_m2(double b, double z)
 {
-  return jj_m2(b, 0.5 * z) * 0.0625;
+    return jj_m2(b, 0.5 * z) * 0.0625;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
